@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -55,6 +55,22 @@ class _ArjunFacade:
     def __init__(self):
         self.__version = pkg_resources.require("arjuna")[0].version
 
+    def load(self, raw_args):
+        from arjuna.tpi.parser.text import _TextResource
+        from arjuna.interface.cli import ArjunaCLI
+        reader = _TextResource("header.txt")
+        print(reader.read().format(version=self.__version))
+        reader.close()
+
+        print("Parsing CLI Options...")
+        cli = ArjunaCLI(raw_args)
+        # Initialize the Arjuna Core as per CLI options
+        print("Intializing Arjuna...")
+        cli.init()
+
+        print("Loading Arjuna core to allow third party test engine to take over test execution...")
+        cli.load()
+
     def launch(self, raw_args):
         from arjuna.tpi.parser.text import _TextResource
         from arjuna.interface.cli import ArjunaCLI
@@ -77,7 +93,8 @@ from arjuna.tpi.error import *
 from arjuna.tpi.constant import *
 from arjuna.core.constant import *
 from arjuna.tpi.tracker import track
-from arjuna.tpi.helper.arjtype import nvpair, nvpairs, withx, Screen, attr, node, Point, Offset, NetworkPacketInfo
+from arjuna.tpi.helper.arjtype import nvpair, nvpairs, withx, Screen, attr, node, bnode, fnode, Point, Offset, NetworkPacketInfo, oneof, axes
+from arjuna.tpi.helper.extract import pos
 from arjuna.tpi.helper.audit import HardCoded
 from arjuna.tpi.helper.arjtype import ProcessedKeyDict
 from arjuna.tpi.helper.datetime import Time, DateTime, DateTimeDelta, DateTimeStepper
@@ -98,7 +115,9 @@ from arjuna.tpi.data.record import *
 from arjuna.tpi.data.generator import Random, Locales, generator, composite, composer
 from arjuna.tpi.data.entity import data_entity
 
-from arjuna.tpi.guiauto.meta.locator import GuiWidgetLocator
+from arjuna.tpi.guiauto.meta.locator import GuiWidgetDefinition
+gui_widget_def = GuiWidgetDefinition
+widget = GuiWidgetDefinition
 from arjuna.tpi.guiauto.model.app import GuiApp
 from arjuna.tpi.guiauto.model.page import GuiPage
 from arjuna.tpi.guiauto.model.section import GuiSection
