@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -199,6 +199,10 @@ class With(metaclass=_WithXMetaClass):
     def bnode(cls, map):
         return With(WithType.BNODE, map)
 
+    @classmethod
+    def axes(cls, map):
+        return With(WithType.AXES, map)
+
     @classmethod
     def value(cls, value):
         return With(WithType.VALUE, value)
@@ -269,7 +273,7 @@ class Locator:
             new_locator.set_value(locator.lvalue.create_formatted_locator(**fargs))
             return new_locator
 
-        fmt_locator_value = self.lvalue.replace("\{", "__LB__").replace("}", "__RB__")
+        fmt_locator_value = str(self.lvalue).replace("\{", "__LB__").replace("}", "__RB__")
 
         # Find params
         matches = re.findall(pattern, fmt_locator_value)
