@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -27,7 +27,7 @@ from arjuna.core.constant import *
 from arjuna.tpi.parser.text import _TextResource
 from arjuna.core.types import constants
 from arjuna.core.adv.py import *
-from arjuna.interface.enums import CommandEnum
+from arjuna.interface.enums import CommandEnum, TargetEnum
 
 from .parser import *
 from .command import *
@@ -47,21 +47,9 @@ class ArjunaCLI:
 
         # Create re-usable parses for command arguments
         new_project_parser = NewProjectParser()
-        project_parser = ProjectParser()
-        run_parser = RunParser()
-        run_default_group_parser = RunDefaultGroupParser()
-        session_parser = SessionParser()
-        stage_parser = StageParser()
-        group_parser = GroupParser()
-        pickers_parser = PickersParser()
 
         # Create primary command handlers
         self.create_project = CreateProject(subparsers, [new_project_parser])
-        self.run_project = RunProject(subparsers, [project_parser, run_parser, run_default_group_parser])
-        self.run_session = RunSession(subparsers, [project_parser, run_parser, session_parser])
-        self.run_stage = RunStage(subparsers, [project_parser, run_parser, stage_parser])
-        self.run_group = RunGroup(subparsers, [project_parser, run_parser, group_parser])
-        self.run_selected = RunSelected(subparsers, [project_parser, run_parser, run_default_group_parser, pickers_parser])
 
     def init(self):
         time.sleep(0.1)
@@ -111,3 +99,38 @@ class ArjunaCLI:
         # Delegation using Arjuna's Enum based switch-case equivalent
         switch = EnumSwitch(execute_cases, (self.arg_dict,))
         switch(command_enum)
+
+    def load(self):
+        command = self.arg_dict['command']
+        del self.arg_dict['command']
+
+        if not command:
+            command = "run-project"
+
+        # Delegation dictionary for primary command description
+        desc_cases = {
+            # CommandEnum.LAUNCH_SETU: "Launching Setu",
+            CommandEnum.CREATE_PROJECT: "Creating new project",
+            CommandEnum.RUN_PROJECT: "Loading Project",
+            CommandEnum.RUN_GROUP: "Loading group",
+            CommandEnum.RUN_SELECTED: "Loading selected tests"
+        }
+
+        # Hyphens in commands are replaced with underscores for enum conversion
+        # So, create-project is internally referred as CREATE_PROJECT
+        command_enum = CommandEnum[command.upper().replace("-", "_")]
+
+        print(desc_cases[command_enum] + "...")
+
+        # Delegation dictionary for primary command choices
+        # Respective command object's 'execute' method is the handler.
+        execute_cases = {
+            CommandEnum.RUN_PROJECT: (self.run_project.load, ),
+            CommandEnum.RUN_GROUP: (self.run_group.load, ),
+            CommandEnum.RUN_SELECTED: (self.run_selected.load, )
+        }
+
+        # Delegation using Arjuna's Enum based switch-case equivalent
+        switch = EnumSwitch(execute_cases, (self.arg_dict,))
+        switch(command_enum)
+
