@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -15,13 +15,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from arjuna.tpi.guiauto.meta.locator import GuiWidgetLocator
+from arjuna.tpi.guiauto.meta.locator import GuiWidgetDefinition
 from arjuna.tpi.tracker import track
 
-@track("debug")
+@track("trace")
 class GNSLabelFormatter:
     '''
-        Formattter for the GuiWidgetLocator associated with a GNS Label.
+        Formattter for the GuiWidgetDefinition associated with a GNS Label.
 
         It is not created directly by a test author. Created using **.format** call of GNS object associated with a **Gui**.
 
@@ -29,7 +29,7 @@ class GNSLabelFormatter:
             gns: Gui Namespace object
 
         Keyword Arguments:
-            **fargs: Arbitrary key-value pairs to format the GuiWidgetLocator associated with a GNS Label.
+            **fargs: Arbitrary key-value pairs to format the GuiWidgetDefinition associated with a GNS Label.
 
         Note:
             Supports **.** notation for a **GuiWidgetLabel** just like a **GNS** object. For example:
@@ -49,12 +49,22 @@ class GNSLabelFormatter:
         from arjuna import log_debug
         log_debug("Finding element with label: {}, wmd: {} and fargs: {}".format(name, wmd, self.__fargs))
         fmt_wmd = wmd.create_formatted_wmd(**self.__fargs)
+        for k,v in fmt_wmd.meta.relations.items():
+            from arjuna.interact.gui.auto.finder.wmd import GuiWidgetMetaData
+            if type(v) is str:
+                log_debug("Formatting related label {} in relations dict.".format(k))
+                rwmd = self.__gui_def.get_wmd(v)
+                log_debug("Retrieved  GuiWidgetMetaData {} for label {} in relations dict.".format(rwmd, k))
+                log_debug("Formatting with args: {}".format(self.__fargs))
+                frwmd = rwmd.create_formatted_wmd(**self.__fargs)
+                fmt_wmd.meta.relations[k] = self.__gns._locate_with_wmd(frwmd).dispatcher.driver_element
+                log_debug("Replaced label {} with corresponding GuiElement in relations dict.".format(k, frwmd))
         return self.__gns._locate_with_wmd(fmt_wmd)
 
-@track("debug")
-class GuiWidgetLocatorFormatter:
+@track("trace")
+class GuiWidgetDefinitionFormatter:
     '''
-        Formattter for a GuiWidgetLocator created by GuiWidget factory methods.
+        Formattter for a GuiWidgetDefinition created by GuiWidget factory methods.
 
         It is not created directly by a test author. Created using **.format** call of a **Gui** or **GuiElement**.
 
@@ -62,7 +72,7 @@ class GuiWidgetLocatorFormatter:
             creator: **Gui** or **GuiElement**
 
         Keyword Arguments:
-            **fargs: Arbitrary key-value pairs to format the GuiWidgetLocator associated with a GNS Label.
+            **fargs: Arbitrary key-value pairs to format the GuiWidgetDefinition associated with a GNS Label.
 
         Note:
             Supports all GuiWidget factory method calls:
@@ -81,19 +91,19 @@ class GuiWidgetLocatorFormatter:
         self.__creator = creator
         self.__fargs = fargs
 
-    def locator(type="element", **kwargs) -> GuiWidgetLocator:
+    def locator(type="element", **kwargs) -> GuiWidgetDefinition:
         '''
-            Create a GuiWidgetLocator.
+            Create a GuiWidgetDefinition.
 
             Keyword Arguments:
                 type: type of GuiWidget (element, multi_element, dropdown, radio_group)
-                **kwargs: Arbitrary key-value pairs used to construct a **GuiWidgetLocator**
+                **kwargs: Arbitrary key-value pairs used to construct a **GuiWidgetDefinition**
 
             Returns:
-                A `GuiWidgetLocator` as per the arguments to this call and format arugments of this GuiWidgetLocatorFormatter.
+                A `GuiWidgetDefinition` as per the arguments to this call and format arugments of this GuiWidgetDefinitionFormatter.
 
             Note:
-                The format key-value pairs of this `GuiWidgetLocatorFormatter` are used to format the identifiers in the constructed **GuiWidgetLocator**.
+                The format key-value pairs of this `GuiWidgetDefinitionFormatter` are used to format the identifiers in the constructed **GuiWidgetDefinition**.
         '''        
 
     def locate(self, type="element", **kwargs):
@@ -102,15 +112,15 @@ class GuiWidgetLocatorFormatter:
 
             Keyword Arguments:
                 type: type of GuiWidget (element, multi_element, dropdown, radio_group)
-                **kwargs: Arbitrary key-value pairs used to construct a **GuiWidgetLocator**
+                **kwargs: Arbitrary key-value pairs used to construct a **GuiWidgetDefinition**
 
             Returns:
                 An object of type `GuiWidget`. Exact object type depends on the value of **type** attribute. 
 
             Note:
-                The format key-value pairs of this `GuiWidgetLocatorFormatter` are used to format the identifiers in the constructed **GuiWidgetLocator**.
+                The format key-value pairs of this `GuiWidgetDefinitionFormatter` are used to format the identifiers in the constructed **GuiWidgetDefinition**.
         '''
-        return self.__creator.locate(GuiWidgetLocator(type=type, fmt_args=self.__fargs, **kwargs))
+        return self.__creator.locate(GuiWidgetDefinition(type=type, fmt_args=self.__fargs, **kwargs))
 
     def __getattr__(self, factory):
         if factory not in self._FACTORIES:
