@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -20,6 +20,9 @@ from .gui import Gui
 from .section import GuiSection
 from arjuna.interact.gui.auto.finder.wmd import GuiWidgetMetaData
 
+from arjuna import track
+
+@track("debug")
 class GuiDialog(GuiSection):
     '''
         Represents a GUI Dialog. Can be associated with a **GuiApp** or **GuiPage**.
