@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -535,7 +535,7 @@ class Json:
                 Arjuna's `JsonDict` or `JsonList` object or the same object for allow_any = True
         '''
 
-        with open(file_path, 'r') as f:
+        with open(file_path, 'r', encoding='utf-8') as f:
             return cls.from_str(f.read(), allow_any=allow_any)
 
     @classmethod
